Service Coverage
================

Currently, the OTC Extensions cover 13 different services additionally
to the vanilla OpenStack services implemented in OpenStack SDK. Two
services (rds and cce) are currently covered in the documentation
under several service tags. This may change in future.

.. list-table::
    :name: service-coverage
    :widths: 50 120 30 30 30 30
    :header-rows: 1

    * - Endpoint
      - Service
      - GUI
      - CLI
      - SDK
      - Comment
    * - anti_ddos
      - Anti-DDoS
      - X
      - X
      - X
      -
    * - auto_scaling
      - Auto-auto_scaling
      - X
      - X
      - X
      -
    * - cce_v1
      - Cloud Container Engine
      - X
      - X
      - X
      -
    * - cce_v3
      - Cloud Container Engine V2
      - X
      - X
      - X
      -
    * - ces
      - Cloudeye
      - X
      - X
      - X
      -
    * - css
      - Cloud Search Service
      - X
      - X
      - X
      -
    * - cts
      - Clout Trace Service
      - X
      - X
      - X
      -
    * - dcs
      - Distributed Cache Service
      - X
      - X
      - X
      -
    * - deh
      - Dedicated Host
      - X
      - X
      - X
      -
    * - dis
      - Data Ingestion Service
      - X
      - X
      - X
      -
    * - dms
      - Document Management Service
      - X
      - X
      - X
      -
    * - dns
      - Domain Name Service
      - X
      - X
      - X
      -
    * - dws
      - Data Warehouse Service
      - X
      - X
      - X
      -
    * - kms
      - Key Management Service
      - X
      - X
      - X
      -
    * - load_balancer
      - Load Balancer
      - X
      - X
      -
      -
    * - modelarts
      - ModelArts Service
      - X
      - X
      - X
      -
    * - nat
      - Network Address Translation
      - X
      - X
      - X
      -
    * - obs
      - Object Storage Service
      - X
      - X
      - X
      -
    * - rds_v3
      - Relational Database Service
      - X
      - X
      - X
      -
    * - vbs
      - Volume Backup Service
      - X
      - X
      - X
      -
    * - vpc_v2
      - Virtual Private Cloud
      - X
      - X
      - X
      -
    * - vpcep
      - VPC Endpoint Service
      - X
      - X
      - X
      -
